@@ -1,8 +1,7 @@
 
 __all__ = ['alib','waText','waFile','wa','wad','SvgScreen',
     'baseMod','loopMod','menu',
-    'starMessager','wsServer','httpServer','wsCtrl',
-    'bme280','lightSensor','getIR','adder74283','beam']
+    'starMessager','wsServer','httpServer','wsCtrl']
 #init alib
 from .alib import alib
 from .wadapter import Wa,SvgScreen
@@ -17,12 +16,3 @@ from .starMod import baseMod,loopMod,menu
 #init messager and servers
 from .starServer import sm,wsServer,httpServer,wsCtrl
 starMessager = sm
-
-#Drivers
-from . import waDrivers
-bme280 = waDrivers.LoopShowBme
-getIR = waDrivers.getIR
-adder74283 = waDrivers.AdderQ283
-beam = waDrivers.beam
-from . import wLTR390
-lightSensor = wLTR390.getOnce
